@@ -24,7 +24,7 @@ class Storage(object):
     """This is an empty class to store data in it."""
     
     def __init__(self, dict={}):
-        for name, value in dict.iteritems():
+        for name, value in dict.items():
             setattr(self, name, value)
     
     def __repr__(self):
