@@ -18,8 +18,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import core
-import _repr
+from . import core
+from . import _repr
 
 # Functions which are already pythonic enough
 set_parameter = core.set_parameter
